@@ -5,16 +5,19 @@
 #' @author Alex Chubaty and Eliot McIntire
 #' @export
 #' @importFrom magrittr %>%
-#' @importFrom rgdal getGDALVersionInfo
 #'
 getGDALVersion <-  function() {
-  vers <- tryCatch(getGDALVersionInfo(), error = function(e) NA_real_)
-  if (!is.na(vers)) {
-    vers <- strsplit(vers, split = ",")[[1]][1] %>%
-      strsplit(., split = " ") %>%
-      `[[`(1) %>%
-      `[`(2) %>%
-      as.numeric_version(.)
+  if (.requireNamespace("rgdal")) {
+    vers <- tryCatch(rgdal::getGDALVersionInfo(), error = function(e) NA_real_)
+    if (!is.na(vers)) {
+      vers <- strsplit(vers, split = ",")[[1]][1] %>%
+        strsplit(., split = " ") %>%
+        `[[`(1) %>%
+        `[`(2) %>%
+        as.numeric_version(.)
+    }
+  } else {
+    vers <- '0.0.0'
   }
   return(vers)
 }
@@ -106,31 +109,35 @@ checkGDALVersion <- function(version) {
 #' }
 #'
 fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGDAL", TRUE), ...) {
-  if (is(x, "RasterLayer") && requireNamespace("sf") && requireNamespace("fasterize")) {
+  if (!identical(crs(y), crs(x))) {
+    if (!is(y, "sf")) {
+      y <- spTransform(x = y, CRSobj = crs(x))
+    } else {
+      rn <- .requireNamespace("sf")
+      if (isFALSE(rn)) stop("Must install sf package")
+      y <- st_transform(x = y, crs = crs(x))
+    }
+  }
+
+  if (is(y, "SpatialPolygons")) {
+    if (!is(y, "SpatialPolygonsDataFrame")) {
+      y <- SpatialPolygonsDataFrame(Sr = y, data = data.frame(ID = seq(length(y))),
+                                    match.ID = FALSE)
+    }
+  }
+
+  # need to double check that gdal executable exists before going down this path
+  attemptGDAL <- attemptGDAL(x, useGDAL)
+
+  browser(expr = exists("._fastMask_2"))
+
+  if (is(x, "RasterLayer") && requireNamespace("sf", quietly = TRUE) &&
+      requireNamespace("fasterize", quietly = TRUE)) {
     message("fastMask is using sf and fasterize")
 
-    if (!identical(crs(y), crs(x))) {
-      if (!is(y, "sf")) {
-        y <- spTransform(x = y, CRSobj = crs(x))
-      } else {
-        y <- st_transform(x = y, crs = crs(x))
-      }
-    }
-
-    if (is(y, "SpatialPolygons")) {
-      if (!is(y, "SpatialPolygonsDataFrame")) {
-        y <- SpatialPolygonsDataFrame(Sr = y, data = data.frame(ID = seq(length(y))),
-                                      match.ID = FALSE)
-      }
-    }
-
-    # need to double check that gdal executable exists before going down this path
-    attemptGDAL <- attemptGDAL(x, useGDAL)
-
-    browser(expr = exists("._fastMask_2"))
 
     if (attemptGDAL) {
-     # call gdal
+      # call gdal
       message("fastMask is using gdalwarp")
 
       # rasters need to go to same directory that can be unlinked at end without losing other temp files
@@ -238,7 +245,7 @@ bigRastersTmpFile <- function() file.path(bigRastersTmpFolder(), "bigRasInput.ti
 dealWithCores <- function(cores) {
   browser(expr = exists("._dealWithCores_1"))
   if (is.null(cores) || cores == "AUTO") {
-    if (requireNamespace("parallel")) {
+    if (requireNamespace("parallel", quietly = TRUE)) {
       cores <- as.integer(parallel::detectCores() * 0.9)
     } else {
       cores <- 1L
@@ -256,57 +263,63 @@ dealWithCores <- function(cores) {
 }
 
 findGDAL <- function() {
-  gdalPath <- NULL
-  attemptGDAL <- TRUE
-  if (isWindows()) {
-    # Handle all QGIS possibilities
-    a <- dir("C:/", pattern = "Progra", full.names = TRUE)
-    a <- grep("Program Files", a, value = TRUE)
-    a <- unlist(lapply(a, dir, pattern = "QGIS", full.name = TRUE))
-    a <- unlist(lapply(a, dir, pattern = "bin", full.name = TRUE))
+  if (.requireNamespace("gdalUtils")) {
+    gdalPath <- NULL
+    attemptGDAL <- TRUE
+    if (isWindows()) {
+      # Handle all QGIS possibilities
+      a <- dir("C:/", pattern = "Progra", full.names = TRUE)
+      a <- grep("Program Files", a, value = TRUE)
+      a <- unlist(lapply(a, dir, pattern = "QGIS", full.name = TRUE))
+      a <- unlist(lapply(a, dir, pattern = "bin", full.name = TRUE))
 
 
-    possibleWindowsPaths <- c(a, "C:/OSGeo4W64/bin",
-                              "C:/GuidosToolbox/QGIS/bin",
-                              "C:/GuidosToolbox/guidos_progs/FWTools_win/bin",
-                              "C:/Program Files (x86)/Quantum GIS Wroclaw/bin",
-                              "C:/Program Files/GDAL",
-                              "C:/Program Files (x86)/GDAL")
-    message("Searching for gdal installation")
-    gdalInfoExists <- file.exists(file.path(possibleWindowsPaths, "gdalinfo.exe"))
-    if (any(gdalInfoExists))
-      gdalPath <- possibleWindowsPaths[gdalInfoExists]
+      possibleWindowsPaths <- c(a, "C:/OSGeo4W64/bin",
+                                "C:/GuidosToolbox/QGIS/bin",
+                                "C:/GuidosToolbox/guidos_progs/FWTools_win/bin",
+                                "C:/Program Files (x86)/Quantum GIS Wroclaw/bin",
+                                "C:/Program Files/GDAL",
+                                "C:/Program Files (x86)/GDAL")
+      message("Searching for gdal installation")
+      gdalInfoExists <- file.exists(file.path(possibleWindowsPaths, "gdalinfo.exe"))
+      if (any(gdalInfoExists))
+        gdalPath <- possibleWindowsPaths[gdalInfoExists]
+    }
+    gdalPath
+    gdalUtils::gdal_setInstallation(gdalPath)
+
+    if (is.null(getOption("gdalUtils_gdalPath"))) # if it doesn't find gdal installed
+      attemptGDAL <- FALSE
+    attemptGDAL
   }
-  gdalPath
-  gdalUtils::gdal_setInstallation(gdalPath)
-
-  if (is.null(getOption("gdalUtils_gdalPath"))) # if it doesn't find gdal installed
-    attemptGDAL <- FALSE
-  attemptGDAL
 }
 
 attemptGDAL <- function(x, useGDAL) {
-  browser(expr = exists("._attemptGDAL_1"))
-  crsIsNA <- is.na(crs(x))
-  cpim <- canProcessInMemory(x, 3)
-  isTRUEuseGDAL <- isTRUE(useGDAL)
-  forceGDAL <- identical(useGDAL, "force")
-  shouldUseGDAL <- (!cpim && isTRUEuseGDAL || forceGDAL)
-  attemptGDAL <- if (shouldUseGDAL && !crsIsNA) {
-    findGDAL()
-  } else {
-    if (crsIsNA && shouldUseGDAL)
-      message("Can't use GDAL because crs is NA")
-    if (cpim && isTRUEuseGDAL)
-      message("useGDAL is TRUE, but problem is small enough for RAM; skipping GDAL; ",
-              "use GDAL = 'force' to override")
+  if (requireNamespace("gdalUtils", quietly = TRUE)) {
+    browser(expr = exists("._attemptGDAL_1"))
+    crsIsNA <- is.na(crs(x))
+    cpim <- canProcessInMemory(x, 3)
+    isTRUEuseGDAL <- isTRUE(useGDAL)
+    forceGDAL <- identical(useGDAL, "force")
+    shouldUseGDAL <- (!cpim && isTRUEuseGDAL || forceGDAL)
+    attemptGDAL <- if (shouldUseGDAL && !crsIsNA) {
+      findGDAL()
+    } else {
+      if (crsIsNA && shouldUseGDAL)
+        message("Can't use GDAL because crs is NA")
+      if (cpim && isTRUEuseGDAL)
+        message("useGDAL is TRUE, but problem is small enough for RAM; skipping GDAL; ",
+                "use GDAL = 'force' to override")
 
-    FALSE
+      FALSE
+    }
+  } else {
+    message("To use gdal, you need to install gdalUtils; install.packages('gdalUtils')")
+    attemptGDAL <- FALSE
   }
   attemptGDAL
 }
 
-
 maskWithRasterNAs <- function(x, y) {
   if (canProcessInMemory(x, 3) && fromDisk(x))
     x[] <- x[]
