@@ -1,29 +1,27 @@
 ################################################################################
 #' Create reproducible digests of objects in R
 #'
-#' Not all aspects of R objects are captured by current hashing tools in R (e.g.
-#' \code{digest::digest}, \code{knitr} caching,
-#' \code{archivist::cache}). This is mostly because many objects have "transient"
-#' (e.g., functions have environments), or "disk-backed" features. Since
-#' the goal of using reproducibility is to have tools that are not session specific,
-#' this function
-#' attempts to strip all session specific information so that the digest
-#' works between sessions and operating systems. It is tested under many
-#' conditions and object types, there are bound to be others that don't
+#' Not all aspects of R objects are captured by current hashing tools in R
+#' (e.g. \code{digest::digest}, \code{knitr} caching, \code{archivist::cache}).
+#' This is mostly because many objects have "transient"
+#' (e.g., functions have environments), or "disk-backed" features.
+#' Since the goal of using reproducibility is to have tools that are not session specific,
+#' this function attempts to strip all session specific information so that the digest
+#' works between sessions and operating systems.
+#' It is tested under many conditions and object types, there are bound to be others that don't
 #' work correctly.
 #'
 #' @section Classes:
 #'
-#' \code{Raster*} objects have the potential for disk-backed storage.
-#' If the object in the R session is cached using \code{archivist::cache}, only
-#' the header component will be assessed for caching. Thus, objects like this
-#' require more work. Also, because \code{Raster*} can have a built-in representation
-#' for having their data content located on disk, this format will be maintained if the
-#' raster already is file-backed, i.e., to create \code{.tif} or \code{.grd} backed rasters,
-#' use \code{writeRaster} first, then Cache. The .tif or .grd will be copied to the "raster"
-#' subdirectory of the \code{cacheRepo}.
-#' Their RAM representation (as an R object) will still be in the usual
-#' \file{cacheOutputs/} (or formerly \file{gallery/}) directory.
+#' \code{Raster*} objects have the potential for disk-backed storage, thus, require more work.
+#' Also, because \code{Raster*} can have a built-in representation for having their data content
+#' located on disk, this format will be maintained if the raster already is file-backed,
+#' i.e., to create \code{.tif} or \code{.grd} backed rasters, use \code{writeRaster} first,
+#' then \code{Cache}.
+#' The \file{.tif} or \file{.grd} will be copied to the \file{raster/} subdirectory of the
+#' \code{cacheRepo}.
+#' Their RAM representation (as an R object) will still be in the usual  \file{cacheOutputs/}
+#' (or formerly \file{gallery/}) directory.
 #' For \code{inMemory} raster objects, they will remain as binary \code{.RData} files.
 #'
 #' Functions (which are contained within environments) are
@@ -50,8 +48,6 @@
 #'
 #' @return A hash i.e., digest of the object passed in.
 #'
-#' @seealso \code{archivist::cache}.
-#'
 #' @author Eliot McIntire
 #' @export
 #' @importFrom digest digest
@@ -118,29 +114,22 @@ setMethod(
   signature = "ANY",
   definition = function(object, .objects, length, algo, quick,
                         classOptions) {
+    browser(expr = exists("._robustDigest_1"))
     if (is(object, "quosure")) {# can't get this class from rlang via importClass rlang quosure
       object <- eval_tidy(object)
     }
 
     if (is(object, "cluster")) {# can't get this class from rlang via importClass rlang quosure
-      out <- if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-        digest(NULL, algo = algo)
-      else
-        fastdigest(NULL)
+      out <- .doDigest(NULL, algo)
       return(out)
     }
 
-
     # passByReference -- while doing pass by reference attribute setting is faster, is
     #   may be wrong. This caused issue #115 -- now fixed because it doesn't do pass by reference
     object1 <- .removeCacheAtts(object, passByReference = FALSE)
-    if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-      digest(object1, algo = algo)
-    else
-      fastdigest(object1)
+    .doDigest(object1, algo)
 })
 
-
 #' @rdname robustDigest
 #' @export
 setMethod(
@@ -150,8 +139,6 @@ setMethod(
     .robustDigestFormatOnly(object, algo = algo)
 })
 
-
-
 #' @rdname robustDigest
 #' @export
 setMethod(
@@ -175,30 +162,18 @@ setMethod(
           unlist(lapply(object, function(x) {
             browser(expr = exists("hhhh"))
             if (dir.exists(x)) {
-              if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-                digest(basename(x), algo = algo)
-              else
-                fastdigest(basename(x))
+              .doDigest(basename(x), algo)
             } else if (file.exists(x)) {
                 digest(file = x, length = length, algo = algo)
             } else {
-              if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-                digest(x, algo = algo)
-              else
-                fastdigest(x)
+              .doDigest(x, algo)
             }
           }))
         } else {
-          if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-            digest(object, algo = algo)
-          else
-            fastdigest(object)
+          .doDigest(object, algo = algo)
         }
       } else {
-        if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-          digest(object, algo = algo)
-        else
-          fastdigest(object)
+        .doDigest(object, algo = algo)
       }
 })
 
@@ -223,17 +198,11 @@ setMethod(
           digest::digest(file = x, length = length, algo = algo)
         } else {
           # just do file basename as a character string, if file does not exist
-          if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-            digest(.basenames(x, nParentDirs), algo = algo)
-          else
-            fastdigest(.basenames(x, nParentDirs))
+          .doDigest(.basenames(x, nParentDirs), algo = algo)
         }
       })
     } else {
-      if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-        digest(.basenames(object, nParentDirs), algo = algo)
-      else
-        fastdigest(.basenames(object, nParentDirs))
+      .doDigest(.basenames(object, nParentDirs), algo = algo)
     }
 })
 
@@ -256,6 +225,7 @@ setMethod(
   signature = "list",
   definition = function(object, .objects, length, algo, quick, classOptions) {
     object <- .removeCacheAtts(object)
+    browser(expr = exists("._robustDigest_2"))
     lapply(.sortDotsUnderscoreFirst(object), function(x) {
       .robustDigest(object = x, .objects = .objects,
                    length = length,
@@ -271,10 +241,7 @@ setMethod(
   definition = function(object, .objects, length, algo, quick, classOptions) {
     #  Need a specific method for data.frame or else it get "list" method, which is wrong
     object <- .removeCacheAtts(object)
-    if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-      digest(object, algo = algo)
-    else
-      fastdigest(object)
+    .doDigest(object, algo = algo)
 })
 
 #' @rdname robustDigest
@@ -328,10 +295,7 @@ setMethod(
     }
 
     #
-    if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-      digest(aaa, algo = algo)
-    else
-      fastdigest(aaa)
+    .doDigest(aaa, algo = algo)
 })
 
 .basenames <- function(object, nParentDirs) {
@@ -378,8 +342,34 @@ setMethod(
 .robustDigestFormatOnly <- function(object, .objects, length, algo, quick,
                                classOptions) {
   object <- .removeCacheAtts(object)
-  if (isTRUE(getOption("reproducible.useNewDigestAlgorithm")))
-    digest(format(object), algo = algo)
-  else
-    fastdigest(format(object))
+  .doDigest(format(object), algo = algo)
+}
+
+.doDigest <- function(x, algo, length = Inf, file,
+                      newAlgo = getOption("reproducible.useNewDigestAlgorithm"),
+                      cacheSpeed = getOption("reproducible.cacheSpeed", "slow")) {
+  if (missing(algo)) algo = formals(.robustDigest)$algo
+
+  out <- if (!missing(file)) {
+    digest::digest(file = x, algo = algo, length = length)
+  } else {
+    if (isTRUE(newAlgo)) {
+      if (cacheSpeed == "fast") {
+        cacheSpeed <- 2L
+      } else if (cacheSpeed == "slow") {
+        cacheSpeed <- 1L
+      }
+    } else {
+      cacheSpeed <- 2L
+    }
+    out <- if (cacheSpeed == 1) {
+      digest(x, algo = algo)
+    } else if (cacheSpeed == 2) {
+      fastdigest(x)
+    } else {
+      stop("options('reproducible.cacheSpeed') must be 1, 2, 'slow' or 'fast'")
+    }
+    out
+  }
+  out
 }
