@@ -1,11 +1,9 @@
 .onLoad <- function(libname, pkgname) {
+  checkPath(.reproducibleTempCacheDir(), create = TRUE)
+  checkPath(.reproducibleTempInputDir(), create = TRUE)
+
   ## set options using the approach used by devtools
   opts <- options()
-  assignInMyNamespace(".reproducibleTempCacheDir", file.path(tempdir(), "reproducible", "cache"))
-  assignInMyNamespace(".reproducibleTempInputDir",  file.path(tempdir(), "reproducible", "inputs"))
-
-  checkPath(.reproducibleTempCacheDir, create = TRUE)
-  checkPath(.reproducibleTempInputDir, create = TRUE)
   opts.reproducible <- reproducibleOptions()
   toset <- !(names(opts.reproducible) %in% names(opts))
   if (any(toset)) options(opts.reproducible[toset])
@@ -20,8 +18,7 @@
     packageStartupMessage("Using reproducible version ",
                           utils::packageVersion("reproducible"), ".",
                           "\n  'reproducible' has changed the default database backend.",
-                          "\n  See ?reproducibleOptions for details. To revert to the old:",
-                          "\n  options('reproducible.useDBI' = FALSE)")
+                          "\n  See ?reproducibleOptions for details.")
   }
 }
 
@@ -30,16 +27,11 @@
   o <- options()
   o[startsWith(names(o), prefix = "reproducible.")] <- NULL
   options(o)
-  # if (getOption("reproducible.cachePath") == file.path(.reproducibleTempCacheDir)) {
-  #   options(reproducible.cachePath = NULL)
-  # }
-  # if (getOption("reproducible.inputPaths") == file.path(.reproducibleTempInputDir)) {
-  #   options(reproducible.inputPaths = NULL)
-  # }
 }
 
-.reproducibleTempCacheDir <- file.path(tempdir(), "reproducible", "cache")
-.reproducibleTempInputDir <- file.path(tempdir(), "reproducible", "inputs")
+.reproducibleTempPath <- function() normPath(file.path(tempdir(), "reproducible"))
+.reproducibleTempCacheDir <- function() normPath(file.path(tempdir2(), "cache"))
+.reproducibleTempInputDir <- function() normPath(file.path(tempdir2(), "inputs"))
 
 .argsToRemove <- argsToRemove <- unique(c(names(formals(prepInputs)),
                                           names(formals(cropInputs)),
