@@ -15,7 +15,7 @@ opt <- options("reproducible.useCache" = "devMode")
 clearCache(tmpDir, ask = FALSE)
 centralTendency <- function(x)
   mean(x)
-funnyData <- c(1,1,1,1,10)
+funnyData <- c(1, 1, 1, 1, 10)
 uniqueUserTags <- c("thisIsUnique", "reallyUnique")
 ranNumsB <- Cache(centralTendency, funnyData, cacheRepo = tmpDir,
                   userTags = uniqueUserTags) # sets new value to Cache
@@ -38,5 +38,20 @@ options(opt)
 
 # For more in depth uses, see vignette
 \dontrun{
+  # To use Postgres, set environment variables with the required credentials
+  if (requireNamespace("RPostgres")) {
+    Sys.setenv(PGHOST = "server.url")
+    Sys.setenv(PGPORT = 5432)
+    Sys.setenv(PGDATABASE = "mydatabase")
+    Sys.setenv(PGUSER = "mydbuser")
+    Sys.setenv(PGPASSWORD = "mysecurepassword")
+
+    conn <- DBI::dbConnect(RPostgres::Postgres())
+    options("reproducible.conn" = conn)
+
+    # Will use postgres for cache data table, and tempdir() for saved R objects
+    Cache(rnorm, 1, cacheRepo = tempdir())
+  }
+
   browseVignettes(package = "reproducible")
 }
